@@ -1,5 +1,24 @@
 /* -*- mode: c; indent-tabs-mode: t; c-basic-offset: 8; -*- */
 
+static GIFunctionInfo *
+_find_struct_method (GIStructInfo *info, const gchar *method)
+{
+	/* g_struct_info_find_method is broken for class structs like
+	 * GtkWidgetClass, so we search manually.  See
+	 * <https://bugzilla.gnome.org/show_bug.cgi?id=700338>. */
+	gint n_methods;
+	gint i;
+	n_methods = g_struct_info_get_n_methods (info);
+	for (i = 0; i < n_methods; i++) {
+		GIFunctionInfo *method_info =
+			g_struct_info_get_method (info, i);
+		if (strEQ (g_base_info_get_name (method_info), method))
+			return method_info;
+		g_base_info_unref (method_info);
+	}
+	return NULL;
+}
+
 static GIFunctionInfo *
 _find_enum_method (GIEnumInfo *info, const gchar *method)
 {
@@ -25,7 +44,7 @@ get_function_info (GIRepository *repository,
                    const gchar *namespace,
                    const gchar *method)
 {
-	dwarn ("%s: %s, %s, %s\n", G_STRFUNC, basename, namespace, method);
+	dwarn ("%s, %s, %s\n", basename, namespace, method);
 
 	if (namespace) {
 		GIFunctionInfo *function_info = NULL;
@@ -48,7 +67,7 @@ get_function_info (GIRepository *repository,
 			break;
 		    case GI_INFO_TYPE_BOXED:
 		    case GI_INFO_TYPE_STRUCT:
-			function_info = g_struct_info_find_method (
+			function_info = _find_struct_method (
 				(GIStructInfo *) namespace_info,
 				method);
 			break;
@@ -166,12 +185,12 @@ get_signal_info (GIBaseInfo *container_info, const gchar *signal_name)
 
 /* Caller owns return value. */
 static gchar *
-sythesize_gtype_name (GIBaseInfo *info)
+synthesize_gtype_name (GIBaseInfo *info)
 {
 	const gchar *namespace = g_base_info_get_namespace (info);
 	const gchar *name = g_base_info_get_name (info);
 	if (0 == strncmp (namespace, "GObject", 8) ||
-	    0 == strncmp (namespace, "GLib", 4))
+	    0 == strncmp (namespace, "GLib", 5))
 	{
 		namespace = "G";
 	}
@@ -180,12 +199,12 @@ sythesize_gtype_name (GIBaseInfo *info)
 
 /* Caller owns return value. */
 static gchar *
-sythesize_prefixed_gtype_name (GIBaseInfo *info)
+synthesize_prefixed_gtype_name (GIBaseInfo *info)
 {
 	const gchar *namespace = g_base_info_get_namespace (info);
 	const gchar *name = g_base_info_get_name (info);
 	if (0 == strncmp (namespace, "GObject", 8) ||
-	    0 == strncmp (namespace, "GLib", 4))
+	    0 == strncmp (namespace, "GLib", 5))
 	{
 		namespace = "G";
 	}
@@ -206,12 +225,12 @@ get_gtype (GIRegisteredTypeInfo *info)
 		}
 	}
 	if (!gtype || gtype == G_TYPE_NONE) {
-		gchar *full_name = sythesize_gtype_name (info);
+		gchar *full_name = synthesize_gtype_name (info);
 		gtype = g_type_from_name (full_name);
 		g_free (full_name);
 	}
 	if (!gtype || gtype == G_TYPE_NONE) {
-		gchar *full_name = sythesize_prefixed_gtype_name (info);
+		gchar *full_name = synthesize_prefixed_gtype_name (info);
 		gtype = g_type_from_name (full_name);
 		g_free (full_name);
 	}
